@@ -114,7 +114,7 @@ typedef unsigned long   uint32;
 #endif
 typedef unsigned char   uint8_t;
 typedef unsigned short  uint16_t;
-#ifdef _WIN32
+#if defined(_WIN32) && !defined (HS_TYPES_H_)
 typedef unsigned long   uint32_t;
 #endif
 
@@ -631,16 +631,19 @@ typedef unsigned short ADDRESS_FAMILY;
 ** these XXX_PROFILE_SUPPORTED defines are used to track the platforms where
 ** Service Profiles for optional modules are supported.
 ** All platforms: VPN
-** Windows: NAM, Telemetry and Web Security 
-*/
+** Windows: NAM, Web Security, ISE Posture and FireAMP
+ */
 #define NAM_PROFILE_SUPPORTED
-#define TELEMETRY_PROFILE_SUPPORTED
 #define WEBSEC_PROFILE_SUPPORTED
+#define ISEPOSTURE_PROFILE_SUPPORTED
+#define FIREAMP_PROFILE_SUPPORTED
 #elif defined(PLATFORM_DARWIN)
 /*
-** OS X: Web Security
+** OS X: Web Security, ISE Posture, FireAMP
 */
 #define WEBSEC_PROFILE_SUPPORTED
+#define ISEPOSTURE_PROFILE_SUPPORTED
+#define FIREAMP_PROFILE_SUPPORTED
 #endif
 
 #if defined(_WIN32) || defined(PLATFORM_DARWIN) || (defined(PLATFORM_LINUX) && !defined(PLATFORM_ANDROID))
@@ -694,9 +697,9 @@ typedef unsigned short ADDRESS_FAMILY;
 #endif
 
 /*
-** Public Proxy support is only implemented on Windows and Linux desktop platforms
+** Public Proxy support is only implemented on Windows and Linux and mac desktop platforms
 */
-#if (defined(_WIN32) || defined(PLATFORM_LINUX)) && !defined(PRODUCT_TYPE_SSA)
+#if (defined(_WIN32) || defined(PLATFORM_LINUX) || defined(PLATFORM_DARWIN)) && !defined(PRODUCT_TYPE_SSA)
 #define PUBLIC_PROXY_SUPPORTED
 #endif
 
@@ -751,8 +754,6 @@ typedef unsigned short ADDRESS_FAMILY;
 #if (defined(_WIN32) && !defined(_WIN32_WCE))
 // support Service Control Plugins if defined
 #define SERVICE_PLUGIN
-// support Telemetry Plugin if defined
-#define TELEMETRY_PLUGIN
 // support PhoneHome Plugin if defined
 #define PHONEHOME_PLUGIN
 #elif defined(PLATFORM_DARWIN)
@@ -775,9 +776,7 @@ typedef unsigned short ADDRESS_FAMILY;
 /*
  * TLS 1.2 is not supported in 3.x versions of AnyConnect.  Support shall begin in the 4.0 release.
  */
-#if defined(ANYCONNECT_RELEASE_4_OR_HIGHER)
 #define TLS_1_2_SUPPORTED
-#endif
 
 /* END OF MACRO HELL */
 #endif /*__GENDEFS_H*/
